@@ -227,7 +227,7 @@ def get_file_contents(filename: str = None, blob: bytes = None,
 
 
 def get_file_contents_text(filename: str = None, blob: bytes = None,
-                           encoding = None,
+                           encoding: str = None,
                            **kwargs) -> str:
     """Returns string contents of a file, or blob."""
     binary_contents = get_file_contents(filename=filename, blob=blob, **kwargs)
@@ -871,11 +871,11 @@ def availability_anything() -> bool:
 ext_map = {
     # Converter functions must be of the form func(filename, blob, **kwargs):
     # Availability must be either a boolean or a function that takes no params.
-    '.doc': {
-        CONVERTER: convert_doc_to_text,
-        AVAILABILITY: availability_doc,
+    '.csv': {
+        CONVERTER: get_file_contents_text,
+        AVAILABILITY: True,
     },
-    '.dot': {
+    '.doc': {
         CONVERTER: convert_doc_to_text,
         AVAILABILITY: availability_doc,
     },
@@ -887,18 +887,26 @@ ext_map = {
         CONVERTER: convert_docx_to_text,
         AVAILABILITY: True,
     },
-    '.html': {
-        CONVERTER: convert_html_to_text,
-        AVAILABILITY: True,
+    '.dot': {
+        CONVERTER: convert_doc_to_text,
+        AVAILABILITY: availability_doc,
     },
     '.htm': {
         CONVERTER: convert_html_to_text,
         AVAILABILITY: True,
     },
+    '.html': {
+        CONVERTER: convert_html_to_text,
+        AVAILABILITY: True,
+    },
     '.log': {
         CONVERTER: get_file_contents_text,
         AVAILABILITY: True,
     },
+    '.msg': {
+        CONVERTER: get_file_contents_text,
+        AVAILABILITY: True,
+    },
     '.odt': {
         CONVERTER: convert_odt_to_text,
         AVAILABILITY: True,
@@ -911,14 +919,14 @@ ext_map = {
         CONVERTER: convert_rtf_to_text,
         AVAILABILITY: availability_rtf,
     },
-    '.xml': {
-        CONVERTER: convert_xml_to_text,
-        AVAILABILITY: True,
-    },
     '.txt': {
         CONVERTER: get_file_contents_text,
         AVAILABILITY: True,
     },
+    '.xml': {
+        CONVERTER: convert_xml_to_text,
+        AVAILABILITY: True,
+    },
     None: {  # fallback
         CONVERTER: convert_anything_to_text,
         AVAILABILITY: availability_anything,
